@@ -13,7 +13,7 @@ def get_parameters():
     # N is batch size; D_in is input dimension;
     # H is hidden dimension; D_out is output dimension.
     N, D_in, H, D_out = 64, 1000, 100, 10
-    num_epochs = 50
+    num_epochs = 10
     data_loader = eu.examples_data_generator(N, D_in, D_out)
     data_loader_steps = 100
     return N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps
@@ -40,7 +40,7 @@ def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
     # NOTICE!!! WE USE verbose=1 TO SEE THE PRINTS FOR THIS EXAMPLE, BUT YOU MIGHT PREFER TO USE verbose=0 or verbose=2
     # BECAUSE ON BATCH LEVEL IT WILL PRINT A LOT 
     callbacks = [   
-                    SchedulerStep(apply_on_phase=Phase.BATCH_END, apply_on_states=State.TRAIN, verbose=1), #CAN ALSO BE apply_on_states=[State.TRAIN]
+                    SchedulerStep(apply_on_phase=Phase.BATCH_END, apply_on_states=State.TRAIN, verbose=1), #CAN ALSO BE IN FORM OF ARRAY - apply_on_states=[State.TRAIN]
                     StatsPrint(apply_on_phase=Phase.EPOCH_END)
                 ]
 
