@@ -39,6 +39,9 @@ class StatsPrint(CallbackBase):
             result.add(metric_names)
         elif isinstance(metric_names, Iterable):
             result = set(metric_names)
+        
+        if len(result) == 0:
+            print('[StatsPrint][WARNING] - no metric_names provided')
         return result
 
     def _get_print_from_monitor_result(self, monitor_result: CallbackMonitorResult) -> str:
